%define dotests 1

Summary:        Antivirus Toolkit
License:        GPL-2.0-only
Group:          Productivity/Security
Name:		clamav
Version:        1.0.7
Release:	2
Epoch:          1
Url:            https://www.clamav.net
Source0:	https://www.clamav.net/downloads/production/clamav-%{version}.tar.gz
Source1:        rustc

# This patch is not required in future versions.
Patch1:         clamav-1.0.7-lresolv.patch

BuildRequires:	bzip2-devel >= 1.0.8
BuildRequires:	curl-devel >= 8.7.0
#%if %{toolchain} == "gcc"
BuildRequires:	libgcc >= 10.3.0
#%endif

#Please add rust is needed whenever rust is available as RPMS.
#BuildRequires:  /opt/freeware/bin/rustc

BuildRequires:	libiconv >= 1.17
BuildRequires:	json-c-devel >= 0.17
BuildRequires:	xz-libs >= 5.4.3
BuildRequires:	ncurses-devel >= 6.4
BuildRequires:	pcre-devel >= 8.44
BuildRequires:	libxml2-devel >= 2.12.6
BuildRequires:	zlib-devel >= 1.2.13
BuildRequires:	libtool-ltdl >= 2.4.7

Requires:	bzip2 >= 1.0.8
Requires:	curl >= 8.7.0
#%if %{toolchain} == "gcc"
Requires:	libgcc >= 10.3.0
#%endif
Requires:	libiconv >= 1.17
Requires:	json-c >= 0.17
Requires:	xz-libs >= 5.4.3
Requires:	ncurses >= 6.4
Requires:	pcre >= 8.44
Requires:	libxml2 >= 2.12.6
Requires:	zlib >= 1.2.13
#%if %{toolchain} == "gcc"
Requires:	libstdc++ >= 10.3.0
#%endif
Requires:	libtool-ltdl >= 2.4.7
Requires:	AIX-rpm >= 7.2.5.3

%description
ClamAV is an antivirus engine designed for detecting trojans,
viruses, malware and other malicious threats. It is the de-facto
standard for mail gateway scanning. It provides a multi-threaded
scanning daemon, command line utilities for on-demand file scanning,
and a tool for automatic signature updates. The core ClamAV library
provides numerous file format detection mechanisms, file unpacking
support, archive support, and multiple signature languages for
detecting threats.

%package devel
Summary:    Header files and libraries for the Clam Antivirus scanner
Group:      Development/Libraries
Requires:   %{name} = %{epoch}:%{version}-%{release}

%description devel
This package contains headerfiles and libraries which are needed to
build applications using clamav.

%prep
%setup -q -n clamav-clamav-1.0.7
rm -rf clamav-clamav-1.0.7 
git clone https://github.com/Cisco-Talos/clamav.git
mv clamav clamav-clamav-1.0.7
cd clamav-clamav-1.0.7 
git checkout clamav-1.0.7

%build

#export CC="%{__cc__}"
#export CXX="%{__cxx__}"
#This is to make sure rustc has all the flags it needs to escape toc overflow error.
#This needs to be worked with the community.
cp %{SOURCE1} .
export PATH=$PWD:$PATH
which rustc

cd libclamav_rust
cargo update
cargo b --release

cd ../
pwd

/usr/bin/patch -p0 < /home/buildusr/rpmbuild/SOURCES/clamav-1.0.7-lresolv.patch

export CC=gcc
export CXX=g++
export AR="/usr/bin/ar"
export AS="/usr/bin/as"
export OBJECT_MODE=64
export CFLAGS="-D_ALL_SOURCE -maix64 -pthread -I/opt/freeware/include -fPIC -O2 -I/usr/include "
export LDR_CNTRL=MAXDATA=0xD0000000@DSA
export CXXFLAGS="-D_ALL_SOURCE -maix64 -pthread  -I/opt/freeware/include -fPIC -O2 -I/usr/include"

export LDFLAGS="-Wl,-blibpath:/usr/local/lib:/usr/lib:/lib -L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/local/lib -lbsd -lcrypt"
export PATH=$PWD:$PATH
which rustc


ulimit -d unlimited
ulimit -m unlimited

cmake  . -B build -D ENABLE_TESTS=ON -D DATABASE_DIRECTORY=/var/lib/clamav -D CMAKE_INSTALL_MANDIR=/opt/freeware/man -D APP_CONFIG_DIRECTORY=/opt/freeware/etc/clamav -D CMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir}/clamav -D CMAKE_INSTALL_PREFIX="/opt/freeware/" -D ENABLE_JSON_SHARED=OFF -D JSONC_INCLUDE_DIR=/opt/freeware/include/json-c  -D JSONC_LIBRARY=/opt/freeware/lib/libjson-c.a -DCMAKE_AIX_SHARED_LIBRARY_ARCHIVE=ON -DENABLE_MILTER=OFF


cmake --build build

if [ "%{dotests}" == 1 ]
then
  cd build
  (ctest || true)
fi

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

# install on 64bit mode
export OBJECT_MODE=64
export DESTDIR=${RPM_BUILD_ROOT}
cmake --install build

mkdir -p ${RPM_BUILD_ROOT}/var/lib/%{name}

%files
%defattr(-, root, system)
%{_bindir}/*
%{_sbindir}/*
%{_libdir}/*.a
%{_includedir}/*
%{_mandir}/*/*
%{_sysconfdir}/*
%dir /var/lib/%{name}

%files devel 
%defattr(-, root, system)
%{_libdir}/pkgconfig/*
%{_includedir}/*

%changelog
* Thu Oct 10 2024 Aditya Kamath <Aditya.Kamath1@ibm.com> - 1.0.7-2
- Update to change the way we create clamav directory in build.

* Fri Oct 04 2024 Aditya Kamath <Aditya.Kamath1@ibm.com> - 1.0.7-1
- Update to fix CVE-2024-20506, CVE-2024-20505

* Mon Aug 26 2024 Aditya Kamath <Aditya.Kamath1@ibm.com> - 1.0.6-1
- Update to version 1.0.6
 
* Thu Jan 18 2024 Raghu N Arava <raghuara@in.ibm.com> - 0.103.11-1 
- Update to version 0.103.11

* Mon Jun 16 2023 Ayappan <ayappap2@in.ibm.com> - 0.103.8-2
- Fix requires in clamav-devel

* Thu Mar 23 2023 Shubham Gupta <Shubham.Gupta36@ibm.com> - 0.103.8(Added patch for unrar functionality)(clamav-0.103.8-unrar.patch 
- Update to version 0.103.8
 
* Wed May 06 2020 Rishita Saha <risaha16@in.ibm.com> - 0.102.2-1
- Update to version 0.102.2

* Wed Jun 19 2019 Reshma V Kumar <reskumar@in.ibm.com> - 0.101.2-1
- Update to latest version

* Sun Dec 16 2018 Reshma V Kumar <reskumar@in.ibm.com> 0.100.2-1
- First time port for AIX toolbox
